#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MINDENORMAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MINDENORMAL_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mindenormal.hpp>

#endif
